@@ -3,7 +3,7 @@
 #     import ElevationStationsTimeseries
 from adcircpy.outputs.fort61 import ElevationStations, Fort61
 from adcircpy.outputs.fort63 import Fort63
-from adcircpy.outputs.maxele import Maxele
+from adcircpy.outputs.maxele import Maxele, MaximumElevationTimes
 
 # from AdcircPy.Outputs.HarmonicConstituentsElevationStations import \
 #                                         HarmonicConstituentsElevationStations
@@ -12,8 +12,9 @@ __all__ = [
     # '_OutputFactory',
     # 'ElevationStationsTimeseries',
     'Maxele',
-    'ElevationStations', 'Fort61',
+    'MaximumElevationTimes',
+    'ElevationStations',
+    'Fort61',
     'Fort63',
-
     # 'HarmonicConstituentsElevationStations'
 ]
