@@ -8,13 +8,10 @@ import requests
 
 class HighWaterMarks(OrderedDict):
     url = 'https://stn.wim.usgs.gov/STNServices/HWMs/FilteredHWMs.json'
-    params = {'EventType': 2,  # 2 for hurricane
-              'EventStatus': 0}  # 0 for completed
-    default_filter = {"riverine": True,
-                      "non_still_water": True}
+    params = {'EventType': 2, 'EventStatus': 0}  # 2 for hurricane  # 0 for completed
+    default_filter = {'riverine': True, 'non_still_water': True}
 
-    def __init__(self, event_name, event_year,
-                 filter_dict=default_filter, **station_data):
+    def __init__(self, event_name, event_year, filter_dict=default_filter, **station_data):
         super(HighWaterMarks, self).__init__(**station_data)
         self.event_name = event_name
         self.event_year = event_year
@@ -22,8 +19,7 @@ class HighWaterMarks(OrderedDict):
 
     @classmethod
     def from_event_name(cls, event_name, filter_dict=None):
-        event_name, event_year, cls.params[
-            'Event'] = cls._get_event_id_from_name(event_name)
+        event_name, event_year, cls.params['Event'] = cls._get_event_id_from_name(event_name)
         response = requests.get(cls.url, params=cls.params)
         response.raise_for_status()
         json_data = json.loads(response.text)
@@ -32,8 +28,7 @@ class HighWaterMarks(OrderedDict):
             if 'elev_ft' in data.keys():
                 hwm_stations[str(data['hwm_id'])] = data
         filter_dict = cls._init_filter_dict(filter_dict)
-        return cls(event_name, event_year,
-                   filter_dict=filter_dict, **hwm_stations)
+        return cls(event_name, event_year, filter_dict=filter_dict, **hwm_stations)
 
     @classmethod
     def from_csv(cls, event_name, event_year, csvpath, filter_dict=None):
@@ -46,28 +41,33 @@ class HighWaterMarks(OrderedDict):
                 station_id = str(i)
                 hwm_stations[station_id] = dict()
                 for j, column in enumerate(headers):
-                    if column in ['longitude', 'latitude', 'elev_ft',
-                                  'site_latitude', 'site_longitude']:
-                        hwm_stations[station_id][column] = \
-                            float(line[headers.index(column)])
+                    if column in [
+                        'longitude',
+                        'latitude',
+                        'elev_ft',
+                        'site_latitude',
+                        'site_longitude',
+                    ]:
+                        hwm_stations[station_id][column] = float(line[headers.index(column)])
                     elif column in ['hwm_quality_id']:
-                        hwm_stations[station_id][column] = \
-                            int(line[headers.index(column)])
+                        hwm_stations[station_id][column] = int(line[headers.index(column)])
                     else:
-                        hwm_stations[station_id][column] = \
-                            line[headers.index(column)]
-        return cls(event_name, event_year,
-                   filter_dict=filter_dict, **hwm_stations)
+                        hwm_stations[station_id][column] = line[headers.index(column)]
+        return cls(event_name, event_year, filter_dict=filter_dict, **hwm_stations)
 
-    def make_plot(self, axes=None, vmin=None, vmax=None,
-                  extent=None, epsg=None, **kwargs):
+    def make_plot(self, axes=None, vmin=None, vmax=None, extent=None, epsg=None, **kwargs):
         if axes is None:
             fig = plt.figure()
             axes = fig.add_subplot(111)
         for station in self.keys():
-            axes.scatter(self[station]['lon'], self[station]['lat'],
-                         c=self[station]['value'], vmin=vmin, vmax=vmax,
-                         **kwargs)
+            axes.scatter(
+                self[station]['lon'],
+                self[station]['lat'],
+                c=self[station]['value'],
+                vmin=vmin,
+                vmax=vmax,
+                **kwargs
+            )
         return axes
 
     @classmethod
@@ -115,17 +115,25 @@ class HighWaterMarks(OrderedDict):
             events.add((eventName, eventYear, int(item['event_id'])))
         events_dict = dict()
         for name, year, _id in events:
-            events_dict[name.lower() + str(year)] = \
-                {'name': name, 'year': year, 'id': _id}
+            events_dict[name.lower() + str(year)] = {
+                'name': name,
+                'year': year,
+                'id': _id,
+            }
         if event_name.lower() in events_dict.keys():
-            return events_dict[event_name.lower()]['name'], \
-                   events_dict[event_name.lower()]['year'], \
-                   events_dict[event_name.lower()]['id']
+            return (
+                events_dict[event_name.lower()]['name'],
+                events_dict[event_name.lower()]['year'],
+                events_dict[event_name.lower()]['id'],
+            )
         else:
-            eventNames = [event.capitalize()
-                          for event in list(events_dict.keys())]
-            raise Exception('\nEvent name not Found!\n \
-                            Valid event names are:\n{}'.format(eventNames))
+            eventNames = [event.capitalize() for event in list(events_dict.keys())]
+            raise Exception(
+                '\nEvent name not Found!\n \
+                                Valid event names are:\n{}'.format(
+                    eventNames
+                )
+            )
 
     @classmethod
     def _init_filter_dict(cls, filter_dict):
@@ -133,9 +141,16 @@ class HighWaterMarks(OrderedDict):
             filter_dict = cls.default_filter
         return filter_dict
 
-    def _filter(self, excellent=False, good=False, fair=False, poor=False,
-                riverine=False,
-                non_still_water=False, keep_undefined=False):
+    def _filter(
+        self,
+        excellent=False,
+        good=False,
+        fair=False,
+        poor=False,
+        riverine=False,
+        non_still_water=False,
+        keep_undefined=False,
+    ):
         stations_to_delete = set()
         for station in self.keys():
             if 'hwm_quality_id' in self[station].keys():
